qermit.mittask
==============

.. currentmodule:: qermit.taskgraph.mittask.MitTask
.. autoclass:: qermit.taskgraph.mittask.MitTask
    :special-members:
    :members:

.. autoclass:: qermit.taskgraph.mittask.IOTask
